#!/bin/sh
# $Id: t-retry-0.sh,v 1.4 2011/02/01 05:58:26 ca Exp $
# Copyright (c) 2010 Sendmail, Inc. and its suppliers.
#	All rights reserved.
#
# By using this file, you agree to the terms and conditions set
# forth in the LICENSE file which can be found at the top level of
# the sendmail distribution.
#
# ----------------------------------------
# run test program twice:
# 1. write defedb, i.e., try a mail that can't be delivered now
#  check whether MAIL extension data is preserved
# 2. read defedb and try delivery again.
# uses smtp1.sh
# ----------------------------------------

SD=`dirname $0`
if test "${SD}" = "."
then
   SD=../chkmts
fi
. ${SD}/common.sh

for P in smtps smtpc qmgr
do
  chkcto $P COMMERCIAL
  chkcto $P SMI_PRI
done

EDBROK="../qmgr/t-smtpf-edbr.ok"
EDBROK2="../qmgr/t-smtpf-edbr2.ok"

if test X"`uname`" != "XOSF1"
then
while getopts s:V FLAG
do
  case "${FLAG}" in
    s) SKIP="${SKIP} ${OPTARG}";;
    V) VERBOSE=true;;
  esac
done
shift `expr ${OPTIND} - 1`
fi

# cd to right directory (where the programs will be executed).
cd ../qmgr || exit 1
rm -f ${MTMAP}

chkiid()
{
  IID=$1

  for L in ${SSL} ${SCL}
  do
    if grep " iid=${IID}," $L >/dev/null
    then
      :
    else
      $VERBOSE && echo "$0: ERROR: ${TEST}: missing iid=${IID} in $L"
      ERR=true
    fi
  done
}

TEST=1
if echo "${SKIP} X" | ${GREP} -v " ${TEST} " > /dev/null
then
# ----------------------------------------
# 1. "load" defedb, i.e., try a mail that can't be delivered now
# because recipient address is <4xy@...>
#
${CAT} > ${EDBROK} <<EOF
got transaction
	mail=<a01@b.c>
	rcpts_tot=1
	rcpts_left=1
	rcpts_temp=1
	rcpts_perm=0
	state=452
	aqt_rcpts_ar=0
	IID=InJectiOn21
got recipient
	rcpt=<452@y.z>
	aqr_rcpt_idx=0
	aqr_da_idx=0
	aqr_status=452
EOF

# try again in 20s at the earliest (depends on QMGR to double min time)
ERR=false
${SHELL} ${SD}/smtp1.sh -Z "smtpc2" -c '-M IID=InJectiOn21' -O ${EDBROK} -i10 -S"a01@b.c" -R"452@y.z" || ERR=true
# show content of defedb
${VERBOSE} && ${EDBR} -VV
chkiid InJectiOn21
if ${ERR}
then
  ERRS=`expr ${ERRS} + 1 `
  ${VERBOSE} && echo "$0: test ${TEST} failed"
  test X"${MTA_STOPONERROR}" != X && exit 1
fi

${CAT} > ${EDBROK} <<EOF
got transaction
	mail=<a01@b.c>
	rcpts_tot=1
	rcpts_left=1
	rcpts_temp=1
	rcpts_perm=0
	state=452
	aqt_rcpts_ar=0
	IID=InJectiOn21
got recipient
	rcpt=<452@y.z>
	aqr_rcpt_idx=0
	aqr_da_idx=0
	aqr_status=452
got transaction
	mail=<a02@b.c>
	rcpts_tot=1
	rcpts_left=1
	rcpts_temp=1
	rcpts_perm=0
	state=453
	aqt_rcpts_ar=0
	IID=injection42
got recipient
	rcpt=<453@y.z>
	aqr_rcpt_idx=0
	aqr_da_idx=0
	aqr_status=453
EOF

# 2. read defedb and try delivery again.
# try again in 20s at the earliest (depends on QMGR to double min time)
# sleep 60s before terminating MTS
ERR=false
${SHELL} ${SD}/smtp1.sh -Z smtpc2 -c '-M IID=injection42' -E 5 -O ${EDBROK} -i10 -D -I -M -s60 -S"a02@b.c" -R"453@y.z" || ERR=true
${VERBOSE} && ${EDBR} -VV
chkiid injection42
if ${ERR}
then
  ERRS=`expr ${ERRS} + 1 `
  ${VERBOSE} && echo "$0: test ${TEST} failed"
  test X"${MTA_STOPONERROR}" != X && exit 1
fi
fi

# ----------------
if test ${ERRS} -eq 0
then
  rm -f ${EDBROK} ${EDBROK2}
  exit 0
else
  echo "$0: ${ERRS} error(s)"
  exit 1
fi
