/*
 * Copyright (c) 2004, 2005 Sendmail, Inc. and its suppliers.
 *	All rights reserved.
 *
 * By using this file, you agree to the terms and conditions set
 * forth in the LICENSE file which can be found at the top level of
 * the sendmail distribution.
 *
 *	$Id: mcpcnfdef.h,v 1.33 2014/02/19 03:32:44 ca Exp $
 */

#ifndef SM_MCPCNFDEF_H
#define SM_MCPCNFDEF_H 1

#include "sm/generic.h"
#include "sm/error.h"
#include "sm/pwd.h"
#include "sm/sm-conf.h"
#include "sm/net.h"

#if SM_MCPCNFDEF
#define EXTERN
#else
#define EXTERN extern
#endif

EXTERN
sm_conf_definition_T const
wait_names[]
#if SM_MCPCNFDEF
=
{
{ SM_CONF_DEF_MAGIC,
	"nostartaccept", sm_conf_type_choice_value, SE_FL_ACCEPT|SE_FL_W4REQ,
	0, NULL, 0, NULL, NULL, NULL,
	"wait for an incoming connection then start a process to handle it"
	SM_LC_NO_ISSET	SM_LC_SET_MAGIC(0) },
{ SM_CONF_DEF_MAGIC,
	"accept",	sm_conf_type_choice_value, SE_FL_ACCEPT,
	0, NULL, 0, NULL, NULL, NULL,
	"bind to socket and start process which will handle connections"
	SM_LC_NO_ISSET	SM_LC_SET_MAGIC(0) },
{ SM_CONF_DEF_MAGIC,
	"pass",		sm_conf_type_choice_value, SE_FL_PASS,
	0, NULL, 0, NULL, NULL, NULL,
	"bind to socket, start process which will handle connections, pass fd via pass_fd_socket"
	SM_LC_NO_ISSET	SM_LC_SET_MAGIC(0) },
{ SM_CONF_DEF_MAGIC,
	"wait",		sm_conf_type_choice_value, SE_FL_WAIT,
	0, NULL, 0, NULL, NULL, NULL,
	"just start processes, wait for their termination"
	SM_LC_NO_ISSET	SM_LC_SET_MAGIC(0) },
{ SM_CONF_DEF_MAGIC,
	"start_and_wait",	sm_conf_type_choice_value, SE_FL_WAIT,
	0, NULL, 0, NULL, NULL, NULL,
	"just start processes, wait for their termination"
	SM_LC_NO_ISSET	SM_LC_SET_MAGIC(0) },

CONF_SENTINEL
}
#endif /* SM_MCPCNFDEF */
;

EXTERN
sm_conf_definition_T
mcp_listen_def[]
#if SM_MCPCNFDEF
=
{

{ SM_CONF_DEF_MAGIC,
  "listen_socket",	sm_conf_type_union,
	offsetof(servtab_T, se_socket.sckspc_type),
	sizeof(sockspec_T),
	"inet", SM_CONF_FLAG_KEEP_DEFAULT, sock_spec_definitions,
	NULL, NULL, NULL
	SM_LC_NO_ISSET	SM_LC_SET_MAGIC(0) },

CONF_SENTINEL
}
#endif /* SM_MCPCNFDEF */
;

EXTERN
sm_conf_definition_T
mcp_listen_defs[]
#if SM_MCPCNFDEF
=
{
{ SM_CONF_DEF_MAGIC, "socket",		sm_conf_type_union,
	offsetof(servtab_T, se_sockets), sizeof(sockspec_T),
	NULL, 0, sock_spec_definitions,
	NULL, NULL, "listener"
	SM_LC_NO_ISSET	SM_LC_SET_MAGIC(0) },

{ SM_CONF_DEF_MAGIC, "n", sm_conf_type_array_n,
	offsetof(servtab_T, se_socket_n), sizeof(uint),
	NULL, 0, sock_spec_definitions, NULL, NULL, "number of listen sockets"
	SM_LC_NO_ISSET	SM_LC_SET_MAGIC(0) },

CONF_SENTINEL
}
#endif /* SM_MCPCNFDEF */
;

/*
**  NOTE: See mcpcnfs.h!
**  Is there a way to generate this file from it?
*/

#if STANDALONE
# define pass_id_chk	NULL
#else
sm_conf_definition_check_T pass_id_chk;
#endif

EXTERN
sm_conf_definition_T
mcp_defs[]
#if SM_MCPCNFDEF
=
{
#if 0
{ SM_CONF_DEF_MAGIC,
  "name",		sm_conf_type_string,
	offsetof(servtab_T, se_prg),		0,		 "",
	SM_CONF_FLAG_STRICTLY_REQUIRED	},
#endif /* 0 */
#if 0
{ SM_CONF_DEF_MAGIC,
  "protocol",		sm_conf_type_string,
	offsetof(servtab_T, se_proto),		0,		 "_" },
#endif /* 0 */

{ SM_CONF_DEF_MAGIC, "listen_socket",		sm_conf_type_array,
	0, SM_LISTENERS_MAX, NULL,
	SM_CONF_FLAG_MULTIPLE|SM_CONF_FLAG_FLAT|SM_CONF_FLAG_KEEP_DEFAULT,
	mcp_listen_defs,
	NULL,	NULL, NULL
	SM_LC_NO_ISSET	SM_LC_SET_MAGIC(0) },

{ SM_CONF_DEF_MAGIC,
  "processes_min",	sm_conf_type_u32,
	offsetof(servtab_T, se_minchild),	sizeof(int),	"1",
	0,	NULL,	NULL,	NULL,
	"minimum number of processes"
	SM_LC_NO_ISSET	SM_LC_SET_MAGIC(0) },
{ SM_CONF_DEF_MAGIC,
  "processes_max",	sm_conf_type_u32,
	offsetof(servtab_T, se_maxchild),	sizeof(int),	"1",
	0,	NULL,	NULL,	NULL,
	"maximum number of processes"
	SM_LC_NO_ISSET	SM_LC_SET_MAGIC(0) },
{ SM_CONF_DEF_MAGIC,
  "listen_len",	sm_conf_type_u32,
	offsetof(servtab_T, se_listen_len),	sizeof(int),	"64",
	0,	NULL,	NULL,	NULL,
	"backlog parameter for listen(2)"
	SM_LC_NO_ISSET	SM_LC_SET_MAGIC(0) },
{ SM_CONF_DEF_MAGIC,
  "pass_fd_socket",	sm_conf_type_string,
	offsetof(servtab_T, se_exsock),		0,		 "",
	0,	NULL,	NULL,	NULL,
	"path of Unix domain socket to exchange file descriptor"
	SM_LC_NO_ISSET	SM_LC_SET_MAGIC(0) },
{ SM_CONF_DEF_MAGIC,
  "user",		sm_conf_type_string,
	offsetof(servtab_T, se_user),		0,		 "",
	SM_CONF_FLAG_STRICTLY_REQUIRED,
	NULL,	NULL,	NULL,
	"run process as user"
	SM_LC_NO_ISSET	SM_LC_SET_MAGIC(0) },
{ SM_CONF_DEF_MAGIC,
  "group",		sm_conf_type_string,
	offsetof(servtab_T, se_group),		0,		 "",
	0,	NULL,	NULL,	NULL,
	"run process as group"
	SM_LC_NO_ISSET	SM_LC_SET_MAGIC(0) },
{ SM_CONF_DEF_MAGIC,
  "restart_dependencies",	sm_conf_type_argv,
	offsetof(servtab_T, se_restartdep),	SM_MCP_MAXRESTARTDEP,	NULL,
	0,	NULL,	NULL,	NULL,
	"list of services to restart in case of failure"
	SM_LC_NO_ISSET	SM_LC_SET_MAGIC(0) },
{ SM_CONF_DEF_MAGIC,
  "pass_id",		sm_conf_type_string,
	offsetof(servtab_T, se_pass_id),	0,		 NULL,
	0,	NULL,	pass_id_chk,	NULL,
	"pass id to process in argument list with this option"
	SM_LC_NO_ISSET	SM_LC_SET_MAGIC(0) },
{ SM_CONF_DEF_MAGIC,
  "use_id_in_logfile_name",		sm_conf_type_bool,
	offsetof(servtab_T, se_logf_id),	sizeof(bool),	 "0",
	0,	NULL,	NULL,	NULL,
	"use id to create name of logfile: Logdir name id . log"
	SM_LC_NO_ISSET	SM_LC_SET_MAGIC(0) },
{ SM_CONF_DEF_MAGIC,
  "path",		sm_conf_type_string,
	offsetof(servtab_T, se_server),		0,		 NULL,
	SM_CONF_FLAG_STRICTLY_REQUIRED,
	NULL,	NULL,	NULL,
	"path to program"
	SM_LC_NO_ISSET	SM_LC_SET_MAGIC(0) },
{ SM_CONF_DEF_MAGIC,
  "arguments",		sm_conf_type_string,
	offsetof(servtab_T, se_args),		0,		 NULL,
	SM_CONF_FLAG_STRICTLY_REQUIRED,
	NULL,	NULL,	NULL,
	"arguments for program"
	SM_LC_NO_ISSET	SM_LC_SET_MAGIC(0) },
{ SM_CONF_DEF_MAGIC,
  "working_directory",		sm_conf_type_string,
	offsetof(servtab_T, se_workdir),		0,		 NULL,
	0,	NULL,	NULL,	NULL,
	"working directory (chdir(2))"
	SM_LC_NO_ISSET	SM_LC_SET_MAGIC(0) },
{ SM_CONF_DEF_MAGIC,
  "failure_max",	sm_conf_type_u32,
	offsetof(servtab_T, se_failed_max),	sizeof(int),	NULL,
	0,	NULL,	NULL,	NULL,
	"maximum number of failures"
	SM_LC_ISSET(offsetof(servtab_T, se_failed_max_isset))	SM_LC_SET_MAGIC(0) },
{ SM_CONF_DEF_MAGIC,
  "start_action",		sm_conf_type_choice,
	offsetof(servtab_T, se_flags),		sizeof(uint),
	"wait", SM_CONF_FLAG_STRICTLY_REQUIRED, wait_names,
	NULL,	NULL,
	"how to handle program"
	SM_LC_NO_ISSET	SM_LC_SET_MAGIC(0) },
{ SM_CONF_DEF_MAGIC,
  "mcp_type",		sm_conf_type_choice,
	offsetof(servtab_T, se_flags),		sizeof(uint),
	"wait", SM_CONF_FLAG_KEEP_DEFAULT, wait_names,
	NULL,	NULL,
	"how to handle program"
	SM_LC_NO_ISSET	SM_LC_SET_MAGIC(0) },

CONF_SENTINEL
}
#endif /* SM_MCPCNFDEF */
;

EXTERN
sm_conf_definition_T
mcp_global_defs[]
#if SM_MCPCNFDEF
=
{
{ SM_CONF_DEF_MAGIC, "CDB_base_directory",	sm_conf_type_string,
	offsetof(mcp_cnf_T, mcp_cnf_cdb_base),	0,
	"",		SM_CONF_FLAG_KEEP_DEFAULT,
	NULL, NULL, NULL, NULL
	SM_LC_NO_ISSET	SM_LC_SET_MAGIC(0) },

{ SM_CONF_DEF_MAGIC, "SMTPC_socket",	sm_conf_type_string,
	offsetof(mcp_cnf_T, mcp_cnf_smtpcsock),	0,
	NULL, SM_CONF_FLAG_KEEP_DEFAULT, NULL, NULL, NULL, NULL
	SM_LC_NO_ISSET SM_LC_SET_MAGIC(0)
	},
{ SM_CONF_DEF_MAGIC, "SMTPS_socket",	sm_conf_type_string,
	offsetof(mcp_cnf_T, mcp_cnf_smtpssock),	0,
	NULL, SM_CONF_FLAG_KEEP_DEFAULT, NULL, NULL, NULL, NULL
	SM_LC_NO_ISSET SM_LC_SET_MAGIC(0)
	},
{ SM_CONF_DEF_MAGIC, "SMAR_socket",	sm_conf_type_string,
	offsetof(mcp_cnf_T, mcp_cnf_smarsock),	0,
	NULL, SM_CONF_FLAG_KEEP_DEFAULT, NULL, NULL, NULL, NULL
	SM_LC_NO_ISSET SM_LC_SET_MAGIC(0)
	},
{ SM_CONF_DEF_MAGIC, "hostname",		sm_conf_type_string,
	offsetof(mcp_cnf_T, mcp_cnf_hostname),	0,
	NULL, SM_CONF_FLAG_KEEP_DEFAULT, NULL, NULL, NULL, NULL
	SM_LC_NO_ISSET SM_LC_SET_MAGIC(0)
	},

CONF_SENTINEL
}
#endif /* SM_MCPCNFDEF */
;

#undef EXTERN

#endif /* SM_MCPCNFDEF_H */
