/*
 * Copyright (c) 2002-2006, 2011 Sendmail, Inc. and its suppliers.
 *	All rights reserved.
 *
 * By using this file, you agree to the terms and conditions set
 * forth in the LICENSE file which can be found at the top level of
 * the sendmail distribution.
 *
 * $Id: sccnf.h,v 1.35 2011/08/12 16:36:40 ca Exp $
 */

#ifndef SCCNF_H
#define SCCNF_H 1

#include "sm/generic.h"
#include "sm/time.h"
#include "sm/net.h"
#include "sm/io.h"
#include "sm/sm-conf.h"
#include "sm/logcnfdef.h"
#include "sm/mcpcnfs.h"
#include "sm/tlscnf.h"

#if SC_SESS_FEATS
/* client features (per session) */
struct sc_se_feat_S
{
	char		*scsf_name;
	uint32_t	 scsf_flags;
	uchar		 scsf_name_isset;
#if MTA_USE_TLS
	tls_cnf_T	 scsf_cnf_tls;
#endif
};
typedef struct sc_se_feat_S sc_se_feat_T, *sc_se_feat_P;

/* client feature declarations */
struct sc_se_feats_S
{
	sc_se_feat_T	*scsfs_feat;
	uint			 scsfs_n;
};
typedef struct sc_se_feats_S sc_se_feats_T, *sc_se_feats_P;
#endif /* SC_SESS_FEATS */

/* SMTPC configuration context */
typedef struct sc_cnf_S		sc_cnf_T, *sc_cnf_P;
struct sc_cnf_S
{
	sm_magic_T	 sm_magic;
	sm_conf_T	*sc_cnf_smc;		/* parsed configuration */
	char		*sc_cnf_conffile;	/* name of configuration file */
	char		*sc_cnf_section;	/* name of section to use */
	char		*sc_cnf_smtpcsock;	/* SMTP Client/QMGR socket */
	const char	*sc_cnf_smtpcsock_abs;
	char		*sc_cnf_smtpcsock_alloc;
	char		*sc_cnf_cdb_base;	/* Base name for CDB */
	char		*sc_cnf_lmtpsock;
	const char	*sc_cnf_lmtpsock_abs;
	char		*sc_cnf_lmtpsock_alloc;
	char		*sc_cnf_hostname;
	uint		 sc_cnf_id;
	int			 sc_cnf_port;
	sm_ipaddr_T	 sc_cnf_sink;	/* if set: connect only to this sink */

	/*
	**  Thread throttling parameters (all numbers are per listening socket).
	**  Zero values mean use default.
	*/

	/* Max number of "spare" threads */
	uint		 sc_cnf_max_wait_threads;

	/* Min number of "spare" threads */
	uint		 sc_cnf_min_wait_threads;

	/* Max number threads */
	uint		 sc_cnf_max_threads;

	uint32_t	 sc_cnf_cflags;	/* SMTPC configuration flags */
	sm_intvl_T	 sc_cnf_timeout;	/* timeout for I/O */
	uint		 sc_cnf_wait4srv; /* how long to wait for QMGR? */
	uint32_t	 sc_cnf_qmgr_tmo; /* timeout for qmgr communication */
	uint		 sc_cnf_loglevel;
	sm_logspec_T	 sc_cnf_log;
	int		 sc_cnf_debug;	/* debug level */
#if 0
//	char		*sc_cnf_logdir;
#endif
#if FFR_CLIENT_BIND
	sm_ipaddr_T	 sc_cnf_bind;	/* if set: bind to this address */
#endif

#if SC_SESS_FEATS
	sc_se_feats_T	 sc_cnf_se_feats;
#endif
#if MTA_USE_TLS
	tls_cnf_T	 sc_cnf_tls;
#endif
#if SC_TEST
	uint		 sc_cnf_tests;
#endif

	MCP_STRUCTS(sc_cnf_T, sc_cnf)
};

void sc_prt_cnf(sc_cnf_P _sc_cnf, sm_file_T *_fp, bool _all);

#endif /* SCCNF_H */
