/*
 * Copyright (c) 2011 Sendmail, Inc. and its suppliers.
 *	All rights reserved.
 *
 * By using this file, you agree to the terms and conditions set
 * forth in the LICENSE file which can be found at the top level of
 * the sendmail distribution.
 */

#include "sm/generic.h"
SM_RCSID("@(#)$Id: hdr.c,v 1.7 2011/10/10 22:41:58 ca Exp $")

#include "sm/assert.h"
#include "sm/error.h"

#if MTA_USE_DKIM
#include "sm/dkim.h"

/*
**  DKH_NEW -- create new hdr entry and append it to the list
**
**	Parameters:
**		dkhhd -- head of header list
**		pdkh -- (pointer to) header entry (output)
**
**	Returns:
**		usual sm_error code
*/

sm_ret_T
dkh_new(dkhhd_P dkhhd, dkh_P *pdkh)
{
	dkh_P dkh;

	SM_ASSERT(pdkh != NULL);
	SM_ASSERT(dkhhd != NULL);
	dkh = sm_zalloc(sizeof(*dkh));
	if (NULL == dkh)
		goto enomem;
	DKH_APP(dkhhd, dkh);
	*pdkh = dkh;
	return SM_SUCCESS;

  enomem:
	return sm_error_temp(SM_EM_DKIM, ENOMEM);
}

/*
**  DKHL_FREE -- free entire header list
**
**	Parameters:
**		dkhhd -- head of header list
**
**	Returns:
**		SM_SUCCESS
*/

sm_ret_T
dkhl_free(dkhhd_P dkhhd)
{
	dkh_P dkh;

	if (dkhhd == NULL)
		return SM_SUCCESS;
	while (!DKH_EMPTY(dkhhd)) {
		dkh = DKH_FIRST(dkhhd);
		DKH_REMOVE(dkhhd);
		SM_STR_FREE(dkh->dkh_hdr_n);
		SM_STR_FREE(dkh->dkh_hdr_v);
		SM_FREE(dkh);
	}
	return SM_SUCCESS;
}
#endif /* MTA_USE_DKIM */
