#!/bin/sh
# $Id: t-dkim-2.sh,v 1.13 2011/01/14 17:55:41 ca Exp $
# Copyright (c) 2010 Sendmail, Inc. and its suppliers.
#	All rights reserved.
#
# By using this file, you agree to the terms and conditions set
# forth in the LICENSE file which can be found at the top level of
# the sendmail distribution.
#
# ----------------------------------------
# test dkim signing, "relaxed" body/header canonicalization
# ----------------------------------------

test -s stop && exit 1              

SD=`dirname $0`
if test "${SD}" = "."
then
   SD=../libdkim
fi
ERRS=0
PRG=./t-dkim-1
BODY=msg
OUT=t-dkim-2.out

if $PRG -C | grep MTA_USE_DKIM >/dev/null
then
  :
else
   echo "SKIPPED: $0: $PRG not compiled with MTA_USE_DKIM"
   exit 0
fi

VERBOSE=false
if test X"`uname`" != "XOSF1"
then
while getopts s:V FLAG
do
  case "${FLAG}" in
    s) SKIP="${SKIP} ${OPTARG}";;
    V) VERBOSE=true;;
  esac
done
shift `expr ${OPTIND} - 1`
fi

# ----------------------------------------
# relaxed body
TEST=1
ERR=false
H="3h44hVEPIImk1LStuM0LHplXSjdpK+7G0sB44W85dVk="
SIG="LTzPv0wTq83vZY0jvfE1c4hiByoqirFbjmwZrl/uR9BD2cR/WIj7NCvlYqmKwdm/br5OMsNg57H4AtTfv969CX/EAPJNHGyfn8nyDr3XYGa/ziXKVbfwrgXk7JcICSKrwkcle3J32W1mVswbbdXcN12rdJSKdzPsIYZfJb6l4zE="

if echo " ${SKIP} X" | grep -v " ${TEST} " > /dev/null
then
cat >$BODY <<EOF
From: "This A. User" <user@example.com>
To: Not Really <recipient@sendmail.net>
Subject: test DKIM signing with MeTA1
Message-Id: <12345.abcde@example.net>
Date: Fri, 17 Dec 2010 17:20:05 -0800 (PST)

This is the message body.  It's nice, isn't it?
It  does not contain anything useful,  but that is the case with most e-mails. 

-- 
2020 Vision Street
Anycity, Anystate 90009
Office ph: (510) 555-1234
Cell ph:   (510) 555-5678
fax:       (510) 555-9000
email: mmtest3@v253.pogonip.net
.
EOF

$PRG -R -k $SD/private.key -m $BODY -h "bh=$H" -S "b=${SIG}" -VV "$@" >$OUT 2>&1 || ERR=true
if $ERR
then
  ERRS=`expr ${ERRS} + 1 `
  ${VERBOSE} && echo "$0: test ${TEST} failed"
  test X"${MTA_STOPONERROR}" != X && exit 1
fi
else
  ${VERBOSE} && echo "$0: test ${TEST} SKIPPED"
fi

# ----------------------------------------
# relaxed header
TEST=2
ERR=false
H="P7M5AsnZKX0CSpQl3w3u9XwzYQ7gDrSE5gSSQy/1W2E="
SIG="Ac3I59vBl5ShKlewD6tRzLxAWlh/aXLxlAPB8j7EDT7AFL6Gm/nrhoOjK89+tBPJKpLqOxFIGzm26pYMaPVleT2eslWiIooWt22HEJuF2lHOQWEaXXJ1fmQf/BViMsCRQ2gfruFxXsdk2lhvObkgkz8LjCGbS/MxeBO1tuatBPo"

if echo " ${SKIP} X" | grep -v " ${TEST} " > /dev/null
then
cat >$BODY <<EOF
From : user@example.com   
To:  recipient@sendmail.net,
	someone, 
 else
Subject: test for  
	DKIM

2020 Vision Street
Anycity, Anystate 90009
Office ph: (510) 555-1234
Cell ph:   (510) 555-5678
fax:       (510) 555-9000
email: mmtest3@v253.pogonip.net
.
EOF

$PRG -r -k $SD/private.key -m $BODY -h "bh=$H" -S "b=${SIG}" -VV "$@" >$OUT 2>&1 || ERR=true
if $ERR
then
  ERRS=`expr ${ERRS} + 1 `
  ${VERBOSE} && echo "$0: test ${TEST} failed"
  test X"${MTA_STOPONERROR}" != X && exit 1
fi
else
  ${VERBOSE} && echo "$0: test ${TEST} SKIPPED"
fi


# ----------------------------------------
# relaxed header/body
TEST=3
ERR=false
H="3h44hVEPIImk1LStuM0LHplXSjdpK+7G0sB44W85dVk="
SIG="RZuM/2woJTkujpoYxFKa7aQbyIHzDu+ZrSxY2qqcXElJfy2Z1K3p0O+CA/a8oT6D4pGtToGhVaRiwqx6PCZvR49tP5jcuxPFCO6DeVnYM77GjJUmiupf6zMxRlEgtn57/oIL/5YM8iqaTICp7AlPc6s+0+9nRkZaW2RCjvw8kr8="

if echo " ${SKIP} X" | grep -v " ${TEST} " > /dev/null
then
cat >$BODY <<EOF
From : user@example.com 
To:  recipient@sendmail.net, 
	someone,   
 else
Subject: test for
	DKIM

This is the message body.  It's nice, isn't it?
It  does not contain anything useful,  but that is the case with most e-mails. 

-- 
2020 Vision Street
Anycity, Anystate 90009
Office ph: (510) 555-1234
Cell ph:   (510) 555-5678
fax:       (510) 555-9000
email: mmtest3@v253.pogonip.net
.
EOF

$PRG -Rr -k $SD/private.key -m $BODY -h "bh=$H" -S "b=${SIG}" -VV "$@" >$OUT 2>&1 || ERR=true
if $ERR
then
  ERRS=`expr ${ERRS} + 1 `
  ${VERBOSE} && echo "$0: test ${TEST} failed"
  test X"${MTA_STOPONERROR}" != X && exit 1
fi
else
  ${VERBOSE} && echo "$0: test ${TEST} SKIPPED"
fi


# ----------------------------------------
if test ${ERRS} -eq 0
then
  rm -f ${BODY} ${OUT}
  exit 0
else
  echo "${ERRS} error(s)"
  exit 1
fi
