#!/bin/sh
# $Id: t-dkim-conf-1.sh,v 1.12 2013/12/13 02:31:41 ca Exp $
# Copyright (c) 2011 Sendmail, Inc. and its suppliers.
#	All rights reserved.
#
# By using this file, you agree to the terms and conditions set
# forth in the LICENSE file which can be found at the top level of
# the sendmail distribution.
#
# ----------------------------------------
# test dkim signing: skip headers, using a configuration file
# ----------------------------------------

test -s stop && exit 1              

SD=`dirname $0`
if test "${SD}" = "."
then
   SD=../libdkim
fi
. ${SD}/common.sh

# ----------------------------------------
# skip a header
TEST=1
ERR=false
if echo " ${SKIP} X" | grep -v " ${TEST} " > /dev/null
then

H="P7M5AsnZKX0CSpQl3w3u9XwzYQ7gDrSE5gSSQy/1W2E="
SIG="hU1eiDdhQCwLZh1jXoUNF9Sg++8hJfXb4823xLTxNK2y6nMc6M6/iRudoNbF8/ijn/by/PnVE94Jphmzbr9OCfwh0zy+L9wd8ajH7ge7zPjQgUvuiLIzf33GtHYSrSGG4ry+LkUJNcKvjxI7UDSRlnodX6X3V6dWpto6l06yNeU="

cat >$BODY <<EOF
Received: from client.example.com (tls.example.com [10.246.26.40])
	by server.example.com (MTA-5.1.4/MTA-5.1.0) with ESMTP id i1L137WP002508
	(version=TLSv1/SSLv3 cipher=EDH-RSA-DES-CBC3-SHA bits=168 verify=OK);
	Fri, 20 Feb 2010 17:03:08 -0800 (PST)
From: user@example.com
To: recipient@sendmail.net
Subject: test DKIM
Received: from client.example.net (client.example.net [10.246.26.40])
	by client.example.com (MTA-5.1.0/MTA-5.1.0) with ESMTP id i1L137WP002508
	(version=TLSv1/SSLv3 cipher=EDH-RSA-DES-CBC3-SHA bits=168 verify=OK);
	Fri, 20 Feb 2010 17:03:07 -0800 (PST)

2020 Vision Street
Anycity, Anystate 90009
Office ph: (510) 555-1234
Cell ph:   (510) 555-5678
fax:       (510) 555-9000
email: mmtest3@v253.pogonip.net
.
EOF

cat >$CONF <<EOF
skip_header = { "Received:" };
sign {
   domain=example.net;
   selector=default;
   keyfile=${K}/private.key;
}
EOF
$PRG -t ${DKTIME} -f $CONF -m $BODY -h "bh=$H" -S "b=${SIG}" -VV "$@" >$OUT 2>&1 || ERR=true
if $ERR
then
  ERRS=`expr ${ERRS} + 1 `
  ${VERBOSE} && echo "$0: test ${TEST} failed"
  test X"${MTA_STOPONERROR}" != X && exit 1
fi
else
  ${VERBOSE} && echo "$0: test ${TEST} SKIPPED"
fi

# ----------------------------------------
# relaxed body
TEST=2
ERR=false
H="3h44hVEPIImk1LStuM0LHplXSjdpK+7G0sB44W85dVk="
SIG="LTzPv0wTq83vZY0jvfE1c4hiByoqirFbjmwZrl/uR9BD2cR/WIj7NCvlYqmKwdm/br5OMsNg57H4AtTfv969CX/EAPJNHGyfn8nyDr3XYGa/ziXKVbfwrgXk7JcICSKrwkcle3J32W1mVswbbdXcN12rdJSKdzPsIYZfJb6l4zE="

if echo " ${SKIP} X" | grep -v " ${TEST} " > /dev/null
then
cat >$BODY <<EOF
From: "This A. User" <user@example.com>
Received: from client.example.com (tls.example.com [10.246.26.40])
	by server.example.com (MTA-5.1.4/MTA-5.1.0) with ESMTP id i1L137WP002508
	(version=TLSv1/SSLv3 cipher=EDH-RSA-DES-CBC3-SHA bits=168 verify=OK);
	Fri, 20 Feb 2010 17:03:08 -0800 (PST)
To: Not Really <recipient@sendmail.net>
Subject: test DKIM signing with MeTA1
Message-Id: <12345.abcde@example.net>
Date: Fri, 17 Dec 2010 17:20:05 -0800 (PST)

This is the message body.  It's nice, isn't it?
It  does not contain anything useful,  but that is the case with most e-mails. 

-- 
2020 Vision Street
Anycity, Anystate 90009
Office ph: (510) 555-1234
Cell ph:   (510) 555-5678
fax:       (510) 555-9000
email: mmtest3@v253.pogonip.net
.
EOF

cat >$CONF <<EOF
skip_header = { "Received" };
body_canonicalization=relaxed;
sign {
   domain=example.net;
   selector=default;
   keyfile=${K}/private.key;
}
EOF
$PRG -t ${DKTIME} -f $CONF -m $BODY -h "bh=$H" -S "b=${SIG}" -VV "$@" >$OUT 2>&1 || ERR=true
if $ERR
then
  ERRS=`expr ${ERRS} + 1 `
  ${VERBOSE} && echo "$0: test ${TEST} failed"
  test X"${MTA_STOPONERROR}" != X && exit 1
fi
else
  ${VERBOSE} && echo "$0: test ${TEST} SKIPPED"
fi


# ----------------------------------------
# relaxed header
TEST=3
ERR=false
H="P7M5AsnZKX0CSpQl3w3u9XwzYQ7gDrSE5gSSQy/1W2E="
SIG="Ac3I59vBl5ShKlewD6tRzLxAWlh/aXLxlAPB8j7EDT7AFL6Gm/nrhoOjK89+tBPJKpLqOxFIGzm26pYMaPVleT2eslWiIooWt22HEJuF2lHOQWEaXXJ1fmQf/BViMsCRQ2gfruFxXsdk2lhvObkgkz8LjCGbS/MxeBO1tuatBPo"

if echo " ${SKIP} X" | grep -v " ${TEST} " > /dev/null
then
cat >$BODY <<EOF
From : user@example.com   
To:  recipient@sendmail.net,
	someone, 
 else
Received: from client.example.com (tls.example.com [10.246.26.40])
	by server.example.com (MTA-5.1.4/MTA-5.1.0) with ESMTP id i1L137WP002508
	(version=TLSv1/SSLv3 cipher=EDH-RSA-DES-CBC3-SHA bits=168 verify=OK);
	Fri, 20 Feb 2010 17:03:08 -0800 (PST)
Subject: test for  
	DKIM

2020 Vision Street
Anycity, Anystate 90009
Office ph: (510) 555-1234
Cell ph:   (510) 555-5678
fax:       (510) 555-9000
email: mmtest3@v253.pogonip.net
.
EOF

cat >$CONF <<EOF
skip_header = { "Received" };
header_canonicalization=relaxed;
sign {
   domain=example.net;
   selector=default;
   keyfile=${K}/private.key;
}
EOF
$PRG -t ${DKTIME} -f $CONF -m $BODY -h "bh=$H" -S "b=${SIG}" -VV "$@" >$OUT 2>&1 || ERR=true
if $ERR
then
  ERRS=`expr ${ERRS} + 1 `
  ${VERBOSE} && echo "$0: test ${TEST} failed"
  test X"${MTA_STOPONERROR}" != X && exit 1
fi
else
  ${VERBOSE} && echo "$0: test ${TEST} SKIPPED"
fi

# ----------------------------------------
# relaxed header/body
TEST=4
ERR=false
H="3h44hVEPIImk1LStuM0LHplXSjdpK+7G0sB44W85dVk="
SIG="RZuM/2woJTkujpoYxFKa7aQbyIHzDu+ZrSxY2qqcXElJfy2Z1K3p0O+CA/a8oT6D4pGtToGhVaRiwqx6PCZvR49tP5jcuxPFCO6DeVnYM77GjJUmiupf6zMxRlEgtn57/oIL/5YM8iqaTICp7AlPc6s+0+9nRkZaW2RCjvw8kr8="

if echo " ${SKIP} X" | grep -v " ${TEST} " > /dev/null
then
cat >$BODY <<EOF
From : user@example.com 
To:  recipient@sendmail.net, 
	someone,   
 else
Subject: test for
	DKIM
Received: from client.example.com (tls.example.com [10.246.26.40])
	by server.example.com (MTA-5.1.4/MTA-5.1.0) with ESMTP id i1L137WP002508
	(version=TLSv1/SSLv3 cipher=EDH-RSA-DES-CBC3-SHA bits=168 verify=OK);
	Fri, 20 Feb 2010 17:03:08 -0800 (PST)

This is the message body.  It's nice, isn't it?
It  does not contain anything useful,  but that is the case with most e-mails. 

-- 
2020 Vision Street
Anycity, Anystate 90009
Office ph: (510) 555-1234
Cell ph:   (510) 555-5678
fax:       (510) 555-9000
email: mmtest3@v253.pogonip.net
.
EOF


cat >$CONF <<EOF
body_canonicalization=relaxed;
header_canonicalization=relaxed;
skip_header = { "Received" };
sign {
   domain=example.net;
   selector=default;
   keyfile=${K}/private.key;
}
EOF
$PRG -t ${DKTIME} -f $CONF -m $BODY -h "bh=$H" -S "b=${SIG}" -VV "$@" >$OUT 2>&1 || ERR=true
if $ERR
then
  ERRS=`expr ${ERRS} + 1 `
  ${VERBOSE} && echo "$0: test ${TEST} failed"
  test X"${MTA_STOPONERROR}" != X && exit 1
fi
else
  ${VERBOSE} && echo "$0: test ${TEST} SKIPPED"
fi

# ----------------------------------------
# skip headers
TEST=5
ERR=false
if echo " ${SKIP} X" | grep -v " ${TEST} " > /dev/null
then

H="P7M5AsnZKX0CSpQl3w3u9XwzYQ7gDrSE5gSSQy/1W2E="
SIG="hU1eiDdhQCwLZh1jXoUNF9Sg++8hJfXb4823xLTxNK2y6nMc6M6/iRudoNbF8/ijn/by/PnVE94Jphmzbr9OCfwh0zy+L9wd8ajH7ge7zPjQgUvuiLIzf33GtHYSrSGG4ry+LkUJNcKvjxI7UDSRlnodX6X3V6dWpto6l06yNeU="

cat >$BODY <<EOF
Received: from client.example.com (tls.example.com [10.246.26.40])
	by server.example.com (MTA-5.1.4/MTA-5.1.0) with ESMTP id i1L137WP002508
	(version=TLSv1/SSLv3 cipher=EDH-RSA-DES-CBC3-SHA bits=168 verify=OK);
	Fri, 20 Feb 2010 17:03:08 -0800 (PST)
From: user@example.com
X-Something: abc
To: recipient@sendmail.net
X-Other: abc
	?
Subject: test DKIM
Received: from client.example.net (client.example.net [10.246.26.40])
	by client.example.com (MTA-5.1.0/MTA-5.1.0) with ESMTP id i1L137WP002508
	(version=TLSv1/SSLv3 cipher=EDH-RSA-DES-CBC3-SHA bits=168 verify=OK);
	Fri, 20 Feb 2010 17:03:07 -0800 (PST)
X-last: abc
	xyz

2020 Vision Street
Anycity, Anystate 90009
Office ph: (510) 555-1234
Cell ph:   (510) 555-5678
fax:       (510) 555-9000
email: mmtest3@v253.pogonip.net
.
EOF

cat >$CONF <<EOF
skip_header = { "Received:", "X-" };
sign {
   domain=example.net;
   selector=default;
   keyfile=${K}/private.key;
}
EOF
$PRG -t ${DKTIME} -f $CONF -m $BODY -h "bh=$H" -S "b=${SIG}" -VV "$@" >$OUT 2>&1 || ERR=true
if $ERR
then
  ERRS=`expr ${ERRS} + 1 `
  ${VERBOSE} && echo "$0: test ${TEST} failed"
  test X"${MTA_STOPONERROR}" != X && exit 1
fi
else
  ${VERBOSE} && echo "$0: test ${TEST} SKIPPED"
fi



# ----------------------------------------
if test ${ERRS} -eq 0
then
  rm -f ${BODY} ${OUT} ${CONF}
  exit 0
else
  echo "${ERRS} error(s)"
  exit 1
fi
