#!/bin/sh
# $Id: t-mt-2.sh,v 1.13 2013/09/23 21:01:42 ca Exp $
# Copyright (c) 2005, 2006 Sendmail, Inc. and its suppliers.
#	All rights reserved.
#
# By using this file, you agree to the terms and conditions set
# forth in the LICENSE file which can be found at the top level of
# the sendmail distribution.
#
# ------------------------------------------------------------
# Description:
# mailertable routing tests by contacting SMAR, using BDB
# uses t-smar-1, startsmar.sh, t-mm
# ------------------------------------------------------------
#

# path to programs
P=..
TPRG=./t-smar-1
SD=`dirname $0`
if test "${SD}" = "."
then
   SD=../smar
fi
. ${SD}/common.sh

CONF=mt.conf
MAPTYPES=""

if test X"`uname`" != "XOSF1"
then
while getopts s:T:V FLAG
do
  case "${FLAG}" in
    s) SKIP="${SKIP} ${OPTARG}";;
    T) MAPTYPES="${OPTARG}";;
    V) VERBOSE=true;;
  esac
done
shift `expr ${OPTIND} - 1`
fi

rm -f ${SOCK} ${PIDS}

# prepare mailertable
${CAT} > ${MT} <<EOF
host123.meta1.org	[1.2.3.0]
meta1.org	[1.2.3.2]
.meta1.org	[1.2.3.4]
.org		[1.2.3.6]
.		[1.2.3.9]
blank2.org	[1.0.0.65]    [1.0.0.66]     
local.dom	lmtp:
EOF

${MM} -l 0 > ${MMMAPC}

# create aliases map for smar
rm -f ${ALIMAP}
${MM} <<EOF
user:	local:
EOF
if test $? -ne 0
then
  echo t-mm failed
  exit 1
fi

if test X"${MAPTYPES}" = "X"
then
./smar -l 1 | grep ':A:L:.:F' >${MAPC}
MAPTYPES="`sed -e 's/^\([a-zA-Z][a-zA-Z0-9_]*\):A:L:.:F/\1/' < ${MAPC}`"
fi
# list map classes available for t-mm
${MM} -l 0 > ${MMMAPC}
for maptype in ${MAPTYPES}
do

if grep ${maptype} ${MMMAPC} >/dev/null
then

rm -f ${MTMAPDB}
${MM} -t'	' -T ${maptype} -F ${MTMAPDB} < ${MT}

${CAT} > ${CONF} <<EOF
smar {
 map mt { type=${maptype}; file=${MTMAPDB}; }
 mailertable { name=mt; }
}
EOF

# start SMAR
${SHELL} ${SD}/startsmar.sh -m -f ${CONF} ${SMAROPTS} || exit 1

rm -f ${OUT} ${IP} ${OK}

TEST=1
# ----------------------------------------
${VALGRIND} ${TPRG} -M -VVVV '<a@host123.meta1.org>' > ${OUT} 2>&1
grep '^IP' ${OUT} | sort > ${IP}
${CAT} > ${OK} <<EOF
IP[0]=1.2.3.0 [1020300]
EOF
if diff ${OK} ${IP}
then
  :
else
  ERRS=`expr ${ERRS} + 1 `
  echo "$0: test ${TEST} failed."
fi

TEST=2
# ----------------------------------------
${VALGRIND} ${TPRG} -M -VVVV '<a@host124.meta1.org>' > ${OUT} 2>&1
grep '^IP' ${OUT} | sort > ${IP}
${CAT} > ${OK} <<EOF
IP[0]=1.2.3.4 [1020304]
EOF
if diff ${OK} ${IP}
then
  :
else
  ERRS=`expr ${ERRS} + 1 `
  echo "$0: test ${TEST} failed."
fi

TEST=3
# ----------------------------------------
${VALGRIND} ${TPRG} -M -VVVV '<a@meta1.org>' > ${OUT} 2>&1
grep '^IP' ${OUT} | sort > ${IP}
${CAT} > ${OK} <<EOF
IP[0]=1.2.3.2 [1020302]
EOF
if diff ${OK} ${IP}
then
  :
else
  ERRS=`expr ${ERRS} + 1 `
  echo "$0: test ${TEST} failed."
fi

TEST=4
# ----------------------------------------
${VALGRIND} ${TPRG} -M -VVVV '<a@metaX.org>' > ${OUT} 2>&1
grep '^IP' ${OUT} | sort > ${IP}
${CAT} > ${OK} <<EOF
IP[0]=1.2.3.6 [1020306]
EOF
if diff ${OK} ${IP}
then
  :
else
  ERRS=`expr ${ERRS} + 1 `
  echo "$0: test ${TEST} failed."
fi

TEST=5
# ----------------------------------------
${VALGRIND} ${TPRG} -M -VVVV '<a@meta1.com>' > ${OUT} 2>&1
grep '^IP' ${OUT} | sort > ${IP}
${CAT} > ${OK} <<EOF
IP[0]=1.2.3.9 [1020309]
EOF
if diff ${OK} ${IP}
then
  :
else
  ERRS=`expr ${ERRS} + 1 `
  echo "$0: test ${TEST} failed."
fi


TEST=6
# ----------------------------------------
${VALGRIND} ${TPRG} -M -VVVV '<a@blank2.org>' > ${OUT} 2>&1
grep '^IP' ${OUT} | sort > ${IP}
${CAT} > ${OK} <<EOF
IP[0]=1.0.0.65 [1000041]
IP[1]=1.0.0.66 [1000042]
EOF
if diff ${OK} ${IP}
then
  :
else
  ERRS=`expr ${ERRS} + 1 `
  echo "$0: test ${TEST} failed."
fi

TEST=7
# ----------------------------------------
${VALGRIND} ${TPRG} -M -VVVV '<local@local.dom>' > ${OUT} 2>&1
grep '^IP' ${OUT} | sort > ${IP}
${CAT} > ${OK} <<EOF
IP[0]=${MTA_LMTPIPV4D} [${MTA_LMTPIPV4H}]
EOF
if diff ${OK} ${IP}
then
  :
else
  ERRS=`expr ${ERRS} + 1 `
  echo "$0: test ${TEST} failed."
fi

rm -f ${MT} ${OUT} ${IP} ${OK} ${CONF} ${MTMAPDB}

# stop SMAR
for i in `${CAT} ${PIDS}`
do
  kill ${i}
done
# ----------------
# thanks kids for not following the POSIX standard...
if test X"`uname`" = "XLinux"
then
  killall smar
fi

else
  echo "$0: ${maptype} not available for ${MM}"
fi
done


exit ${ERRS}
